class SolarSystem {
  constructor() {
    this.canvas = document.getElementById('solarSystem');
    this.ctx = this.canvas.getContext('2d');
    this.planets = this.initializePlanets();
    this.speed = 1;
    this.showOrbits = true;
    this.selectedPlanet = null;
    this.setupCanvas();
    this.bindEvents();
    this.animate();
  }

  initializePlanets() {
    return [
      { name: 'Sun', radius: 50, color: '#ffd700', x: 0, y: 0 },
      { name: 'Mercury', radius: 10, orbitRadius: 80, color: '#a6a6a6', angle: 0, speed: 0.04 },
      { name: 'Venus', radius: 15, orbitRadius: 120, color: '#e6b800', angle: 0, speed: 0.015 },
      { name: 'Earth', radius: 16, orbitRadius: 170, color: '#4169e1', angle: 0, speed: 0.01 },
      { name: 'Mars', radius: 12, orbitRadius: 220, color: '#ff4d4d', angle: 0, speed: 0.008 },
      { name: 'Jupiter', radius: 30, orbitRadius: 300, color: '#ffa64d', angle: 0, speed: 0.002 },
      { name: 'Saturn', radius: 25, orbitRadius: 380, color: '#ffdb4d', angle: 0, speed: 0.0009 }
    ];
  }

  setupCanvas() {
    const resize = () => {
      this.canvas.width = this.canvas.clientWidth;
      this.canvas.height = this.canvas.clientHeight;
    };
    window.addEventListener('resize', resize);
    resize();
  }

  bindEvents() {
    document.getElementById('speedControl').addEventListener('input', (e) => {
      this.speed = parseFloat(e.target.value);
    });

    document.getElementById('showOrbits').addEventListener('change', (e) => {
      this.showOrbits = e.target.checked;
    });

    document.getElementById('toggleInfo').addEventListener('click', () => {
      document.getElementById('info').classList.toggle('visible');
    });

    document.getElementById('toggleControls').addEventListener('click', () => {
      document.getElementById('controls').classList.toggle('visible');
    });

    this.canvas.addEventListener('click', (e) => this.handleClick(e));
  }

  handleClick(e) {
    const rect = this.canvas.getBoundingClientRect();
    const x = e.clientX - rect.left - this.canvas.width / 2;
    const y = e.clientY - rect.top - this.canvas.height / 2;
    
    this.selectedPlanet = this.planets.find(planet => {
      const dx = planet.x - x;
      const dy = planet.y - y;
      return Math.sqrt(dx * dx + dy * dy) < planet.radius;
    });

    if (this.selectedPlanet) {
      this.updatePlanetInfo();
    }
  }

  updatePlanetInfo() {
    const info = document.getElementById('planetInfo');
    if (this.selectedPlanet) {
      info.innerHTML = `
        <h3>${this.selectedPlanet.name}</h3>
        <p>Orbit Radius: ${this.selectedPlanet.orbitRadius}M km</p>
        <p>Size: ${this.selectedPlanet.radius}k km</p>
      `;
    }
  }

  draw() {
    this.ctx.clearRect(0, 0, this.canvas.width, this.canvas.height);
    this.ctx.save();
    this.ctx.translate(this.canvas.width / 2, this.canvas.height / 2);

    // Draw orbits
    if (this.showOrbits) {
      this.planets.slice(1).forEach(planet => {
        this.ctx.beginPath();
        this.ctx.strokeStyle = 'rgba(255, 255, 255, 0.1)';
        this.ctx.arc(0, 0, planet.orbitRadius, 0, Math.PI * 2);
        this.ctx.stroke();
      });
    }

    // Draw planets
    this.planets.forEach(planet => {
      this.ctx.beginPath();
      this.ctx.fillStyle = planet.color;
      this.ctx.arc(planet.x, planet.y, planet.radius, 0, Math.PI * 2);
      this.ctx.fill();
      
      if (planet === this.selectedPlanet) {
        this.ctx.strokeStyle = '#fff';
        this.ctx.lineWidth = 2;
        this.ctx.stroke();
      }
    });

    this.ctx.restore();
  }

  update() {
    this.planets.slice(1).forEach(planet => {
      planet.angle += planet.speed * this.speed;
      planet.x = Math.cos(planet.angle) * planet.orbitRadius;
      planet.y = Math.sin(planet.angle) * planet.orbitRadius;
    });
  }

  animate() {
    this.update();
    this.draw();
    requestAnimationFrame(() => this.animate());
  }
}

document.addEventListener('DOMContentLoaded', () => {
  new SolarSystem();
});
